﻿(function($) {
    jQuery.fn.pictureMenu = function(options) {
        var defaults = {
            animateTime: 350,         // The duration of the animations
            menuHeight: 150,          // The height of the menu (usually the same as the height of the images)
            menuWidth: 75,            // The length of a menu item (useMenuWidth must be true)
            menuWidthHover: 40,       // The length of the inactive menu items
            menuActiveWidth: 500,     // The length of the active menu items (useMenuActiveWidth must be true)
            menuInactiveHide: 1,      // The opacity of the inactive menu items
            menuBorder: 2,            // The Border between the menu items
            subMenu: ".submenu",      // Selector of the submenu
            useMenuWidth: true,       // If true: use custom menuWidth. If false: use calculated menuWidth
            useMenuActiveWidth: false // If true: use custom menuActiveWidth. If false: use calculated menuActiveWidth
        };

        var o = $.extend(defaults, options);

        return this.each(function() {
            var e = $(this), menuItemsCount, menuWidth, menuItemWidth, Offset, hoverWidth, listWidth;

            // Number of menu items
            menuItemsCount = e.children().length;
            // Length of the whole menu
            menuWidth = e.width();
            // Calculate (or use) the length of the menu items
            if (o.useMenuWidth) {
                menuItemWidth = o.menuWidth;
            } else {
                menuItemWidth = Math.round(menuWidth / menuItemsCount) - o.menuBorder;

                // Calculate the offset
                Offset = (menuItemWidth + o.menuBorder) * menuItemsCount - menuWidth;
                // In case there is an offset, reduce the menu item size
                if (Offset > 0) {
                    menuItemWidth = menuItemWidth - 1;
                }
            }
            // Calculate (or use) the length a menu item can expand
            if (o.useMenuActiveWidth) {
                hoverWidth = o.menuActiveWidth;
            } else {
                hoverWidth = menuWidth - ((menuItemsCount - 1) * (o.menuWidthHover + o.menuBorder));
            }
            // Calculate the length of the menu inside the menu item
            listWidth = hoverWidth - o.menuWidth - 32;

            // Do some magic
            e.css("display", "block")
             .css("height", o.menuHeight + "px")
             .css("overflow", "hidden")
             .children()
             .wrap('<div class="pmWrap" />')
             .wrap('<div class="pmItem" style="width: ' + menuItemWidth + 'px; border-right: solid ' + o.menuBorder + 'px white;" />')
             .addClass("pmItemWrap")
             .mouseenter(function() {
                 // Make the menu items small when your mouse enters the menu
                 e.find(".pmItem").stop().animate({
                     width: o.menuWidthHover,
                     opacity: o.menuInactiveHide
                 }, o.animateTime);
             })
             .mouseleave(function() {
                 // Close the menu when you leave the menu item
                 e.find(".pmItem").stop().animate({
                     width: menuItemWidth,
                     opacity: 1
                 }, o.animateTime).find(o.subMenu).fadeOut("fast");
             })
             .each(function() {
                 // Get the background image
                 var imgBackground = $(this).find("img:first-child").attr("src");
                 
                 // Hide the image and make it a background on the menu item
                 $(this).css("background", "url(" + imgBackground + ")")
                        .css("height", o.menuHeight + "px")
                        .find("img:first-child")
                        .css("display", "none");
                 // Hide the submenu
                 $(this).find(o.subMenu).css("max-width", listWidth + "px").hide();
                 
                 $(this).mouseenter(function() {
                     // Show the menu item when you enter it with your mouse
                     $(this).parent().stop().animate({
                         width: hoverWidth,
                         opacity: 1
                     }, o.animateTime, function() {
                         // When menu is loaded, show the sub menu
                         $(this).find(o.subMenu).fadeIn("normal");
                     });
                 });
             });
        });
    }
})(jQuery);